import { useState } from "react"
import { useParams } from "react-router"
import { GetPlayer } from "../../api/player"
import WithDataFetching from "../../components/withdatafetching"
import Player from "../../types/player"
import ClubHistory from "./club_history"
import Scores from "./scores"
import Sidebar from "./sidebar"

export default function PlayerPage() {
  const { slug } = useParams()

  if (!slug) {
    return <div>No slug</div>
  }
  return (
    <WithDataFetching
      queryKey={["player", slug]}
      queryFn={() => GetPlayer(slug)}
    >
      {(player) => <PlayerLayout player={player} />}
    </WithDataFetching>
  )

  function PlayerLayout({ player }: { player: Player }) {
    const [activeTab, setActiveTab] = useState("club_history")
    const tabs = [
      { id: "club_history", title: "Club History" },
      { id: "scores", title: "Scores" },
    ]
    return (
      <div className="grid h-screen grid-cols-[260px_1fr]">
        <Sidebar player={player}></Sidebar>
        <div className="flex flex-col">
          <div className="flex border-b">
            {tabs.map((tab) => (
              <button
                key={tab.id}
                className={`px-4 py-2 text-center text-sm font-medium ${activeTab === tab.id ? "border-b-2 border-blue-300 text-blue-400" : "text-gray-500 hover:text-gray-700"}`}
                onClick={() => setActiveTab(tab.id)}
              >
                {tab.title}
              </button>
            ))}
          </div>
          <div className="p-6">
            {activeTab === "club_history" && (
              <ClubHistory player={player}></ClubHistory>
            )}
            {activeTab === "scores" && <Scores player={player}></Scores>}
          </div>
        </div>
      </div>
    )
  }
}
